TypeCode class

Constructors

TypeCode(String code)
const
TypeCode.b(String code, {bool? nullable})
factory

Properties

code → String
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
no setter
nonNullableName → String
no setter
nullable → bool
no setter
nullableName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toTypescriptTypeString() → String

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

isNullable(String value) → bool